@@ -6,6 +6,7 @@ import gettext
 import os
 import sys
 import traceback
+import cairo
 
 import gi
 gi.require_version("Gtk", "3.0")
@@ -103,12 +104,30 @@ class MainWindow(object):
         self.startWithFavorites = settings.get_boolean(key)
 
     def getSetGSettingEntries(self):
-        self.dottedfile          = os.path.join(self.path, "dotted.png")
+        self.dottedfile           = os.path.join(self.path, "dotted.png")
         self.pluginlist           = self.settings.get_strv("plugins-list")
         self.offset               = self.settings.get_int("offset")
         self.enableTooltips       = self.settings.get_boolean("tooltips-enabled")
         self.startWithFavorites   = self.settings.get_boolean("start-with-favorites")
 
+    def getRepeatedSeparator(self, pixbuf):
+        area = Gtk.DrawingArea()
+        area.set_hexpand(True)
+        area.set_vexpand(True)
+        def on_draw(widget, cr):
+            alloc = widget.get_allocation()
+            width = max(1, alloc.width)
+            height = max(1, alloc.height)
+            surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf, 1) # dotted.png
+            pattern = cairo.SurfacePattern(surface)
+            pattern.set_extend(cairo.EXTEND_REPEAT)
+            cr.set_source(pattern)
+            cr.rectangle(0, 0, width, height)
+            cr.fill()
+            return False
+        area.connect("draw", on_draw)
+        return area
+
     def PopulatePlugins(self):
         PluginPane = Gtk.EventBox()
         PluginPane.show()
@@ -117,8 +136,6 @@ class MainWindow(object):
         ImageBox = Gtk.EventBox()
         ImageBox.show()
 
-        seperatorImage = GdkPixbuf.Pixbuf.new_from_file(self.dottedfile)
-
         self.plugins = {}
 
         for plugin in self.pluginlist:
@@ -139,13 +156,6 @@ class MainWindow(object):
                     if not MyPlugin.icon:
                         MyPlugin.icon = "mate-logo-icon.png"
 
-                    #if hasattr(MyPlugin, "hideseparator") and not MyPlugin.hideseparator:
-                    #    Image1 = Gtk.Image()
-                    #    Image1.set_from_pixbuf(seperatorImage)
-                    #    if not ImageBox.get_child():
-                    #        ImageBox.add(Image1)
-                    #        Image1.show()
-
                     #print u"Loading plugin '" + plugin + "' : sucessful"
                 except Exception:
                     MyPlugin = Gtk.EventBox() #Fake class for MyPlugin
@@ -171,6 +181,7 @@ class MainWindow(object):
                 MyPlugin.content_holder.show()
 
                 VBox1 = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+                VBox1.get_style_context().add_class("mint-" + plugin.replace("_", "-"))
                 if MyPlugin.heading != "":
                     label1 = Gtk.Label()
                     label1.set_markup("<span size=\"12000\" weight=\"bold\">%s</span>" % MyPlugin.heading)
@@ -181,10 +192,11 @@ class MainWindow(object):
                     label1.show()
                     heading = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL)
                     heading.set_size_request(MyPlugin.width, -1)
-
+                    heading.get_style_context().add_class("mint-title")
                     heading.add(Align1)
                     heading.show()
                     VBox1.pack_start(heading, False, False, 0)
+
                 VBox1.show()
                 #Add plugin to Plugin Box under heading button
                 MyPlugin.content_holder.get_parent().remove(MyPlugin.content_holder)
@@ -226,14 +238,10 @@ class MainWindow(object):
                 PluginPane.show_all()
 
                 if self.plugins and hasattr(MyPlugin, 'hideseparator') and not MyPlugin.hideseparator:
-                    Image1 = Gtk.Image()
-                    Image1.set_from_pixbuf(seperatorImage)
-                    Image1.show()
-                    #ImageBox.add(Image1)
-
-                    Align1 = Gtk.Alignment.new(0, 0, 0, 0)
+                    seperatorImage = GdkPixbuf.Pixbuf.new_from_file(self.dottedfile)
+                    Align1 = Gtk.Alignment.new(0, 0, 1, 1)
                     Align1.set_padding(0, 0, 6, 6)
-                    Align1.add(Image1)
+                    Align1.add(self.getRepeatedSeparator(seperatorImage))
                     ImageBox.add(Align1)
                     ImageBox.show_all()
 
